/*
** Module   : BatchHelper.java
** Abstract : The class provides I/O stubs and error handling for batch mode processing. 
**
** Copyright (c) 2013-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20131104 Created initial version.
** 002 EVL 30140225 The output error message must be disabled in redirected mode in any OS and
**                  Windows background mode.
** 003 GES 20150506 Made this into a simple static helper class.  There is no instance data.
*/

package com.goldencode.p2j.ui.client.chui.driver.batch;

import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.util.*;
import com.goldencode.util.*;

/**
 * The BatchHelper class provides special handling for input output operation for active batch
 * mode.
 */
public class BatchHelper 
{
   /**
    * Default empty constructor.
    */
   private BatchHelper()
   {
   }

   /**
    * Handles incoming input operations for active batch mode.  Generates UnstoppableExitException
    * for active case.
    */
   public static void inputOperation()
   throws UnstoppableExitException
   {
      ErrorManager.displayError(513, "Attempt to read with no current source of input", true);
      throw new UnstoppableExitException("");
   }
   
   /**
    * Handles incoming output operations for active batch mode.  Generates
    * UnstoppableExitException for active case.
    */
   public static void outputOperation()
   throws UnstoppableExitException
   {
      if (!FileChecker.isConsoleRedirected() &&
          (!PlatformHelper.isUnderWindowsFamily() || !OutputManager.isBatchInBackground()))
      {
         ErrorManager.displayError(516,
                                   "Attempt to write with no current output destination", true);
      }
      
      throw new UnstoppableExitException("");
   } 
}
