/*
** Module   : ImageXfer.java
** Abstract : helper to pass an image to the clipboard
**
** Copyright (c) 2011-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20110921 Created initial version.
** 002 GES 20150506 Moved to a driver package.
*/

package com.goldencode.p2j.ui.client.driver.swing;

import java.awt.*;
import java.awt.datatransfer.*;
import java.awt.image.*;
import java.io.*;

/**
 * Provides a convenience class to make it easy to pass an image as a
 * <code>Transferrable</code>.  This is needed to copy data to the
 * clipboard or other data transfer mechanisms such as drag and drop.
 */
public class ImageXfer
implements Transferable
{
   /** The image being transferred. */
   private Image image = null;

   /**
    * Construct an instance with the given image as the data to transfer.
    *
    * @param    image
    *           The image to transfer.
    */
   public ImageXfer(Image image)
   {
      this.image = image;
   }

   /**
    * Provides a list of supported data flavors.
    *
    * @return   An array of data flavors containing a single element that
    *           is <code>DataFlavor.imageFlavor</code>.
    */
   public DataFlavor[] getTransferDataFlavors()
   {
      return new DataFlavor[] { DataFlavor.imageFlavor };
   }

   /**
    * Reports if the given data flavor is supported.
    *
    * @param    flavor
    *           The flavor to check.
    *
    * @return   <code>true</code> if the given flavor equals
    *           <code>DataFlavor.imageFlavor</code>.
    */
   public boolean isDataFlavorSupported(DataFlavor flavor)
   {
      return DataFlavor.imageFlavor.equals(flavor);
   }

   /**
    * Obtains the contained data if it matches a supported data flavor.
    *
    * @param    flavor
    *           The flavor that is needed.
    *
    * @return   The image data if the given flavor equals
    *           <code>DataFlavor.imageFlavor</code>.  Otherwise an
    *           <code>UnsupportedFlavorException</code> is thrown.
    */
   public Object getTransferData(DataFlavor flavor)
   throws UnsupportedFlavorException
   {
      if (!DataFlavor.imageFlavor.equals(flavor))
      {
         throw new UnsupportedFlavorException(flavor);
      }
      
      return image;
   }
}
