/*
** Module   : EditableWidget.java
** Abstract : Implementation of mouse actions required for editable widgets. 
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20141205 Created initial version.
** 002 HC  20150323 WidgetId.getId() renamed to asInt().
** 003 GES 20150501 Removed AWT dependencies and moved to a more generic package.
*/

package com.goldencode.p2j.ui.client.gui.driver;

// this usage of AWT events is intentional, they are being used separately from the AWT/Swing
// event model; no other AWT/Swing usage is occurring in this class
import java.awt.event.MouseEvent;

import com.goldencode.p2j.ui.client.gui.WindowGuiImpl;

/**
 * Implement driver-level mouse behavior for editable widgets.
 */
public class EditableWidget
extends MouseWidgetAction
{
   /**
    * Create a new action and associate with the specified widget.
    * 
    * @param    wid
    *           The widget id.
    */
   public EditableWidget(int wid)
   {
      super(wid);
   }

   /**
    * On mouse entered, set the mouse cursor to {@link CursorType#TEXT}.
    * 
    * @param    e
    *           The mouse event.
    */
   @Override
   public void mouseEntered(MouseEvent e)
   {
      WindowGuiImpl window = (WindowGuiImpl) widget.window();
      gd.selectWindow(window.config().id.asInt());

      gd.setCursor(CursorType.TEXT);
   }
   
   /**
    * On mouse exit, set the mouse cursor to {@link CursorType#DEFAULT}.
    * 
    * @param    e
    *           The mouse event.
    */
   @Override
   public void mouseExited(MouseEvent e)
   {
      WindowGuiImpl window = (WindowGuiImpl) widget.window();
      gd.selectWindow(window.config().id.asInt());

      gd.setCursor(CursorType.DEFAULT);
   }
}
