/*
** Module   : GuiConstants.java
** Abstract : GUI constants
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 MAG 20140508 First version.
** 002 CA  20140805 Explicitly import TerminalOptions, to isolate chui class usage outside of chui
**                  packages.
** 003 MAG 20140902 No longer color constants. System colors used to draw widgets are implemented
**                  at driver level.   
** 004 MAG 20141029 Added scroll bar size and mouse repeat interval parameters.
** 005 CA  20141123 Fixed default scroll bar size; added default caption button size.
** 006 HC  20150510 Improved drawing of caption buttons - they are now more Windows alike. 
** 007 GES 20150424 Removed useless parent class and renamed this class.
*/

package com.goldencode.p2j.ui.client.gui.driver;

/** 
 * Stores the default constants for GUI interface.
 */
public class GuiConstants 
{
   /** The default number of rows of text on the terminal screen. */
   public static int DEF_ROWS = 24;
   
   /** The default number of columns of text on the terminal screen. */
   public static int DEF_COLUMNS = 80;
   
   /** Window border size (in pixels). */
   public final static int BORDER_SIZE = 4;

   /** Default scroll bar size (in pixels) - windows classic theme. */
   public final static int SCROLLBAR_SIZE = 16;
   
   /** Default caption button height (in pixels) - window classic theme. */
   public final static int CAPTION_BUTTON_HEIGHT = 17;

   /** Default caption button width (in pixels) - window classic theme. */
   public final static int CAPTION_BUTTON_WIDTH = CAPTION_BUTTON_HEIGHT + 2;
   
   /** Mouse press repeat time interval */
   public static final int REPEAT_MILLIS = 200;
}
