/*
** Module   : GuiWebPageHandler.java
** Abstract : GUI-specific page handler
**
** Copyright (c) 2015 Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 GES 20150325 Created initial version patterned after the ChuiWebPageHandler.
*/

package com.goldencode.p2j.ui.client.gui.driver.web;

import org.eclipse.jetty.server.*;

import com.goldencode.p2j.cfg.*;
import com.goldencode.p2j.util.*;
import com.goldencode.p2j.web.*;
import com.goldencode.p2j.ui.client.driver.web.*;

/**
 * This code primarily exists to parse the HTML text and substitute place holders, but all the
 * rest of the handler functionality is in the parent class where it can be shared. 
 */
public class GuiWebPageHandler
extends WebPageHandler
{
   /** Configuration. */
   private BootstrapConfig config;
   
   /**
    * Constructor.
    *
    * @param    config
    *           Configuration parameters.
    * @param    root
    *           Prefix for all URLs relating to this page.
    * @param    skel
    *           Fully qualified resource name of the HTML file which should be used.
    */
   public GuiWebPageHandler(BootstrapConfig config, String root, String skel)
   {
      super(config, root, skel);
      this.config = config;
   }
   
   /**
    * Process the given string and make any replacements of parameter
    * values as needed. The replacement placeholder follow the JEE 
    * expression language (EL) format for immediate evaluation. 
    * <p>
    * Example: ${expression} 
    *
    * @param    base
    *           The details and state the request.
    * @param    text
    *           The text line that may need modifications.
    *
    * @return   The new text if a modification occurred or the original text
    *           if no modification was needed.
    */
   protected String handleReplacements(Request base, String text)
   {
      text = super.handleReplacements(base, text);
      
      if (text.contains("${client_title}"))
      {
         text = text.replace("${client_title}", "GUI");
      }
      
      if (text.contains("${isGui}"))
      {
         text = text.replace("${isGui}", "true");
      }
      
      if (text.contains("${height_name}"))
      {
         text = text.replace("${height_name}", "height");
      }                           
      
      if (text.contains("${height_val}"))
      {
         // TODO: where should we get the initial pixel values from?
         text = text.replace("${height_val}", "400");
      }                           
      
      if (text.contains("${width_name}"))
      {
         text = text.replace("${width_name}", "width");
      }
      
      if (text.contains("${width_val}"))
      {
         // TODO: where should we get the initial pixel values from?
         text = text.replace("${width_val}", "600");
      }
      
      if (text.contains("${font.name}"))
      {
         // TODO: where should we get the font cfg from?
         text = text.replace("${font.name}", "unknown");
      }
      
      if (text.contains("${font.size}"))
      {
         // TODO: where should we get the font cfg from?
         text = text.replace("${font.size}", "12");
      }

      if (text.contains("${font.color}"))
      {
         // TODO: where should we get the font cfg from?
         text = text.replace("${font.color}", htmlColor("#FFA500"));
      }

      if (text.contains("${font.background}"))
      {
         // TODO: where should we get the font cfg from?
         text = text.replace("${font.background}", htmlColor("#000000"));
      }

      return text;
   }   
}
